
# If there's no vi link, take over:
if [ ! -r usr/bin/vi ]; then
  ( cd usr/bin ; ln -sf vim vi )
fi
( cd usr/bin ; rm -rf gview )
( cd usr/bin ; ln -sf gvim gview )
( cd usr/bin ; rm -rf rgvim )
( cd usr/bin ; ln -sf gvim rgvim )
( cd usr/bin ; rm -rf rgview )
( cd usr/bin ; ln -sf gvim rgview )
( cd usr/bin ; rm -rf gvimdiff )
( cd usr/bin ; ln -sf gvim gvimdiff )
( cd usr/man/fr/man1 ; rm -rf gvim.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/fr/man1 ; rm -rf gview.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/fr/man1 ; rm -rf rgview.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/fr/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/fr/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/fr/man1 ; rm -rf eview.1.gz )
( cd usr/man/fr/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/fr/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/fr/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/it/man1 ; rm -rf gvim.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/it/man1 ; rm -rf gview.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/it/man1 ; rm -rf rgview.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/it/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/it/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/it/man1 ; rm -rf eview.1.gz )
( cd usr/man/it/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/it/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/it/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/pl/man1 ; rm -rf gvim.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/pl/man1 ; rm -rf gview.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/pl/man1 ; rm -rf rgview.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/pl/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/pl/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/pl/man1 ; rm -rf eview.1.gz )
( cd usr/man/pl/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/pl/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/pl/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf gvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf gview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rgview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf eview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/it.ISO8859-1/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/man1 ; rm -rf gvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/man1 ; rm -rf gview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/man1 ; rm -rf rgview.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/man1 ; rm -rf eview.1.gz )
( cd usr/man/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf gvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf gview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rgview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf eview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/pl.UTF-8/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/pl.UTF-8/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf gvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf gview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rgview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf eview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/fr.ISO8859-1/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf gvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf gview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rgview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf eview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/pl.ISO8859-2/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf gvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf gview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rgview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf eview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/ru.UTF-8/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/ru.UTF-8/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf gvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf gview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rgview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf eview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/ru.KOI8-R/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf gvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf gview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf rgview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf eview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/fr.UTF-8/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/fr.UTF-8/man1 ; ln -sf vim.1.gz rgvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf gvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz gvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf gview.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz gview.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rgview.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rgview.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf gvimdiff.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vimdiff.1.gz gvimdiff.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf eview.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf evim.1.gz eview.1.gz )
( cd usr/man/it.UTF-8/man1 ; rm -rf rgvim.1.gz )
( cd usr/man/it.UTF-8/man1 ; ln -sf vim.1.gz rgvim.1.gz )
